==> complex-float32-parse-0.0.1.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2024 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# parseComplex64

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Parse a string representation of a 64-bit [complex number][@stdlib/complex/float32/ctor].

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="installation">

## Installation

```bash
npm install @stdlib/complex-float32-parse
```

</section>

<section class="usage">

## Usage

```javascript
var parseComplex64 = require( '@stdlib/complex-float32-parse' );
```

#### parseComplex64( str )

Parse a string representation of a 64-bit [complex number][@stdlib/complex/float32/ctor].

```javascript
var parseComplex64 = require( '@stdlib/complex-float32-parse' );
var real = require( '@stdlib/complex-real' );
var imag = require( '@stdlib/complex-imag' );

var str = '5 + 3i';

var z = parseComplex64( str );
// returns <Complex64>

var re = real( z );
// returns 5.0

var im = imag( z );
// returns 3.0
```

For details on the string format, see [Complex64][@stdlib/complex/float32/ctor].

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var parseComplex64 = require( '@stdlib/complex-float32-parse' );
var isComplex64 = require( '@stdlib/assert-is-complex64' );
var real = require( '@stdlib/complex-real' );
var imag = require( '@stdlib/complex-imag' );

var str = '1e3 - 2.75i';

var z = parseComplex64( str );
var bool = isComplex64( z );
// returns true

bool = ( real( z ) === 1e3 );
// returns true

bool = ( imag( z ) === -2.75 );
// returns true
```

</section>

<!-- /.examples -->

<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2024. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/complex-float32-parse.svg
[npm-url]: https://npmjs.org/package/@stdlib/complex-float32-parse

[test-image]: https://github.com/stdlib-js/complex-float32-parse/actions/workflows/test.yml/badge.svg?branch=v0.0.1
[test-url]: https://github.com/stdlib-js/complex-float32-parse/actions/workflows/test.yml?query=branch:v0.0.1

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/complex-float32-parse/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/complex-float32-parse?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/complex-float32-parse.svg
[dependencies-url]: https://david-dm.org/stdlib-js/complex-float32-parse/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/complex-float32-parse/tree/deno
[deno-readme]: https://github.com/stdlib-js/complex-float32-parse/blob/deno/README.md
[umd-url]: https://github.com/stdlib-js/complex-float32-parse/tree/umd
[umd-readme]: https://github.com/stdlib-js/complex-float32-parse/blob/umd/README.md
[esm-url]: https://github.com/stdlib-js/complex-float32-parse/tree/esm
[esm-readme]: https://github.com/stdlib-js/complex-float32-parse/blob/esm/README.md
[branches-url]: https://github.com/stdlib-js/complex-float32-parse/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/complex-float32-parse/main/LICENSE

[@stdlib/complex/float32/ctor]: https://www.npmjs.com/package/@stdlib/complex-float32-ctor

</section>

<!-- /.links -->

==> complex-float32-parse-0.0.2.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2024 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# parseComplex64

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Parse a string representation of a 64-bit [complex number][@stdlib/complex/float32/ctor].

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="installation">

## Installation

```bash
npm install @stdlib/complex-float32-parse
```

</section>

<section class="usage">

## Usage

```javascript
var parseComplex64 = require( '@stdlib/complex-float32-parse' );
```

#### parseComplex64( str )

Parse a string representation of a 64-bit [complex number][@stdlib/complex/float32/ctor].

```javascript
var parseComplex64 = require( '@stdlib/complex-float32-parse' );
var real = require( '@stdlib/complex-float32-real' );
var imag = require( '@stdlib/complex-float32-imag' );

var str = '5 + 3i';

var z = parseComplex64( str );
// returns <Complex64>

var re = real( z );
// returns 5.0

var im = imag( z );
// returns 3.0
```

For details on the string format, see [Complex64][@stdlib/complex/float32/ctor].

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var parseComplex64 = require( '@stdlib/complex-float32-parse' );
var isComplex64 = require( '@stdlib/assert-is-complex64' );
var real = require( '@stdlib/complex-float32-real' );
var imag = require( '@stdlib/complex-float32-imag' );

var str = '1e3 - 2.75i';

var z = parseComplex64( str );
var bool = isComplex64( z );
// returns true

bool = ( real( z ) === 1e3 );
// returns true

bool = ( imag( z ) === -2.75 );
// returns true
```

</section>

<!-- /.examples -->

<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2024. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/complex-float32-parse.svg
[npm-url]: https://npmjs.org/package/@stdlib/complex-float32-parse

[test-image]: https://github.com/stdlib-js/complex-float32-parse/actions/workflows/test.yml/badge.svg?branch=v0.0.2
[test-url]: https://github.com/stdlib-js/complex-float32-parse/actions/workflows/test.yml?query=branch:v0.0.2

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/complex-float32-parse/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/complex-float32-parse?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/complex-float32-parse.svg
[dependencies-url]: https://david-dm.org/stdlib-js/complex-float32-parse/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/complex-float32-parse/tree/deno
[deno-readme]: https://github.com/stdlib-js/complex-float32-parse/blob/deno/README.md
[umd-url]: https://github.com/stdlib-js/complex-float32-parse/tree/umd
[umd-readme]: https://github.com/stdlib-js/complex-float32-parse/blob/umd/README.md
[esm-url]: https://github.com/stdlib-js/complex-float32-parse/tree/esm
[esm-readme]: https://github.com/stdlib-js/complex-float32-parse/blob/esm/README.md
[branches-url]: https://github.com/stdlib-js/complex-float32-parse/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/complex-float32-parse/main/LICENSE

[@stdlib/complex/float32/ctor]: https://www.npmjs.com/package/@stdlib/complex-float32-ctor

</section>

<!-- /.links -->
